@@ -18,17 +18,17 @@ write_report_rtf <- function(rs) {
   
   # Create temp path for text output
   if (debug) {
-    
-    b_path <- file.path(getwd(), "tests/testthat")
-    
-    tmp_path <- file.path(b_path, "output/tmp.txt")
-    rtf_path <- file.path(b_path, "output/tmp.rtf")
-    if (file.exists(tmp_path))
-      file.remove(tmp_path)
-    if (file.exists(rtf_path))
-      file.remove(rtf_path)
-    if (file.exists(orig_path))
-      file.remove(orig_path)
+# 
+#     b_path <- file.path(getwd(), "tests/testthat")
+# 
+#     tmp_path <- file.path(b_path, "output/tmp.txt")
+#     rtf_path <- file.path(b_path, "output/tmp.rtf")
+#     if (file.exists(tmp_path))
+#       file.remove(tmp_path)
+#     if (file.exists(rtf_path))
+#       file.remove(rtf_path)
+#     if (file.exists(orig_path))
+#       file.remove(orig_path)
   } else {
     tmp_dir <- tempdir()
     if (!file.exists(tmp_dir))
@@ -96,11 +96,12 @@ write_rtf_output <- function(rs, ls, rtf_path, orig_path, tmp_dir) {
   # Prepare header
   hdr[length(hdr) + 1] <- "{\\rtf1\\ansi\\deff0 {\\fonttbl {\\f0 Courier;}}"
   if (rs$orientation == "landscape") {
-    hdr[length(hdr) + 1] <- "\\landscape\\horzdoc"
+    #hdr[length(hdr) + 1] <- "\\landscape\\horzdoc"
+    hdr[length(hdr) + 1] <- "\\landscape"
     hdr[length(hdr) + 1] <- paste0("\\paperw", round(rs$page_size[2] * conv),
                                    "\\paperh", round(rs$page_size[1] * conv))
   } else {
-    hdr[length(hdr) + 1] <- "\\vertdoc"
+    #hdr[length(hdr) + 1] <- "\\vertdoc"
     hdr[length(hdr) + 1] <- paste0("\\paperw", round(rs$page_size[1] * conv),
                                    "\\paperh", round(rs$page_size[2] * conv))
   }
